@@ -84,7 +84,7 @@ mod test {
     #[test]
     fn test_large_uints() {
         test_encoding_roundtrip(
-            &u256::from_u64(0x_dead_cafe_4bad_beef).unwrap(),
+            &u256::from(0x_dead_cafe_4bad_beef_u64),
             [
                 0xef, 0xbe, 0xad, 0x4b, 0xfe, 0xca, 0xad, 0xde, 0x00, 0x00,
                 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
@@ -95,7 +95,7 @@ mod test {
         .unwrap();
 
         test_encoding_roundtrip(
-            &u512::from_u64(0x_dead_cafe_4bad_beef).unwrap(),
+            &u512::from(0x_dead_cafe_4bad_beef_u64),
             [
                 0xef, 0xbe, 0xad, 0x4b, 0xfe, 0xca, 0xad, 0xde, 0x00, 0x00,
                 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
@@ -109,7 +109,7 @@ mod test {
         .unwrap();
 
         test_encoding_roundtrip(
-            &u1024::from_u64(0x_dead_cafe_4bad_beef).unwrap(),
+            &u1024::from(0x_dead_cafe_4bad_beef_u64),
             [
                 0xef, 0xbe, 0xad, 0x4b, 0xfe, 0xca, 0xad, 0xde, 0x00, 0x00,
                 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
